==> gigya_flutter_plugin-0.1.7.tar.gz: CHANGELOG.md <==
# 0.0.1
Inital release.

* Business APIs.
* Social login (View documentation for supported providers).
* Web Screen-Sets.
* Interruption handling.

# 0.0.2
Example & documentation.

* Example application updates.
* Documentation updates.

# 0.0.3
Platform alignments

* Fixed Android error not mapped correctly.
* Added dynamic "mapped" field to base GigyaResponse.

# 0.0.4
Core SDKS updates

* Updated Swift SDK 1.2.0.
* Updated Android SDK 5.1.0.

# 0.0.5
Core SDKS update

* Updated Android SDK 5.1.1 (security).

# 0.0.6
Account Model Patch

* Fix to main account model (sessionInfo type).

# 0.1.0

Developer Preview 0.1.0
Flutter 2 and Null-safety

* Android [initialization](https://github.com/SAP/gigya-flutter-plugin#android-setup) update (custom schema) 
* Migrated to Flutter 2 and Null-safety.
* Added Forgot password feature (including example application implementation).
* Added Google sign-in integration to the example application.

# 0.1.1
Android core SDK update.

* Updated Android Core SDK v5.1.3

# 0.1.2
Developer Preview 0.1.2

* Updated Android Core SDK v5.1.4
* Forgot password bug fix.
* Added manual initSDK interface.

# 0.1.3
Developer Preview 0.1.3

* iOS: Fixed crash in forgotPassword.
* iOS: Fixed bug in link account.

# 0.1.4
Developer Preview 0.1.4

* Updated Android Core SDK v5.1.6
* Added setSession interface.

# 0.1.5
Developer Preview 0.1.5

* Added mobile SSO support using CLP.

# 0.1.6

Developer Preview 0.1.6

* Bug fix - Android setSession. Wrong SessonInfo propagation.

# 0.1.7

Developer Preview 0.1.7

* Updated Android Core SDK v5.2.0 containing varius security updates.

==> gigya_flutter_plugin-0.2.0.tar.gz: CHANGELOG.md <==
# 0.0.1
Inital release.

* Business APIs.
* Social login (View documentation for supported providers).
* Web Screen-Sets.
* Interruption handling.

# 0.0.2
Example & documentation.

* Example application updates.
* Documentation updates.

# 0.0.3
Platform alignments

* Fixed Android error not mapped correctly.
* Added dynamic "mapped" field to base GigyaResponse.

# 0.0.4
Core SDKS updates

* Updated Swift SDK 1.2.0.
* Updated Android SDK 5.1.0.

# 0.0.5
Core SDKS update

* Updated Android SDK 5.1.1 (security).

# 0.0.6
Account Model Patch

* Fix to main account model (sessionInfo type).

# 0.1.0

Developer Preview 0.1.0
Flutter 2 and Null-safety

* Android [initialization](https://github.com/SAP/gigya-flutter-plugin#android-setup) update (custom schema) 
* Migrated to Flutter 2 and Null-safety.
* Added Forgot password feature (including example application implementation).
* Added Google sign-in integration to the example application.

# 0.1.1
Android core SDK update.

* Updated Android Core SDK v5.1.3

# 0.1.2
Developer Preview 0.1.2

* Updated Android Core SDK v5.1.4
* Forgot password bug fix.
* Added manual initSDK interface.

# 0.1.3
Developer Preview 0.1.3

* iOS: Fixed crash in forgotPassword.
* iOS: Fixed bug in link account.

# 0.1.4
Developer Preview 0.1.4

* Updated Android Core SDK v5.1.6
* Added setSession interface.

# 0.1.5
Developer Preview 0.1.5

* Added mobile SSO support using CLP.

# 0.1.6

Developer Preview 0.1.6

* Bug fix - Android setSession. Wrong SessionInfo propagation.

# 0.1.7

Developer Preview 0.1.7

* Updated Android Core SDK v5.2.0 containing various security updates.

# 0.2.0

Developer Preview 0.2.0

* Updated Android Core SDK v6.1.0 containing various security updates.
* Bug fix - Fixed account schema parsing.
* Added getSession method.
* Added support for FIDO authentication.
